Learn R Programming

CausalQueries (version 0.0.3)

continue_names: Continue names

Description

Slightly hacky function to continue param_set names in a sequence

Usage

continue_names(x, split = "_")

Arguments

x

A vector with strings of the form c('x_1', 'x_2')

split

String on which to split. String should appear only once in each vector entry.

Value

a vector with parameter names sequentially created with respect to x

Examples

Run this code
# NOT RUN {
x <- c('S_2', 'S_3', 'S_5')
CausalQueries:::continue_names(x)
# }

Run the code above in your browser using DataLab