Learn R Programming

CausalQueries (version 1.0.2)

get_param_dist: Get a distribution of model parameters

Description

Using parameters, priors, or posteriors

Usage

get_param_dist(model, using, n_draws = 4000)

Value

A matrix with the distribution of the parameters in the model

Arguments

model

A causal_model. A model object generated by make_model.

using

A character string. Indicates whether to use `priors`, `posteriors` or `parameters`.

n_draws

An integer. If no prior distribution is provided, generate prior distribution with n_draws number of draws.

Examples

Run this code
get_param_dist(model = make_model('X->Y'), using = 'priors', n_draws = 4)
get_param_dist(model = make_model('X->Y'), using = 'parameters')

Run the code above in your browser using DataLab