Learn R Programming

CausalQueries (version 0.0.3)

get_parameter_matrix: Get parameter matrix

Description

Return parameter matrix if it exists; otherwise calculate it assuming no confounding. The parameter matrix maps from parameters into causal types. In models without confounding parameters correspond to nodal types.

Usage

get_parameter_matrix(model)

Arguments

model

A model created by make_model()

Value

A data.frame, the parameter matrix, mapping from parameters to causal types

Examples

Run this code
# NOT RUN {
model <- make_model('X -> Y')
get_parameter_matrix(model)
# }

Run the code above in your browser using DataLab