powered by
Parameter names taken from P matrix or model if no P matrix provided
P
get_parameter_names(model, include_paramset = TRUE)
A character vector with the names of the parameters in the model
A causal_model. A model object generated by make_model.
causal_model
make_model
Logical. Whether to include the param set prefix as part of the name.
get_parameter_names(make_model('X->Y'))
Run the code above in your browser using DataLab