Learn R Programming

CausalQueries (version 1.0.1)

get_parents: Get list of parents of all nodes in a model

Description

Get list of parents of all nodes in a model

Usage

get_parents(model)

Value

A list of parents in a DAG

Arguments

model

A causal_model. A model object generated by make_model.

Examples

Run this code
model <- make_model('X -> K -> Y')
get_parents(model)

Run the code above in your browser using DataLab