Learn R Programming

CausalQueries (version 1.0.2)

get_parmap: Get parmap: a matrix mapping from parameters to data types

Description

Gets parmap from a model, or generates if not available.

Usage

get_parmap(model, A = NULL, P = NULL)

Value

A matrix

Arguments

model

A causal_model. A model object generated by make_model.

A

A data.frame. Ambiguity matrix. Not required but may be provided to avoid repeated computation for simulations.

P

A data.frame. Parameter matrix. Not required but may be provided to avoid repeated computation for simulations.

Examples

Run this code
get_parmap(model = make_model('X->Y'))

Run the code above in your browser using DataLab