Learn R Programming

CausalQueries (version 1.0.1)

is_improper: Check whether a model is improper

Description

Compute the sum of causal types probabilities. A model is flagged as improper if the sum is different than one.

Usage

is_improper(model)

Value

A logical expression indicating whether a model is improper

Arguments

model

A causal_model. A model object generated by make_model.