list_non_parents: Returns a list with the nodes that are not directly pointing into a node
Description
Returns a list with the nodes that are not directly pointing into a node
Usage
list_non_parents(model, node)
Arguments
model
A causal_model. A model object generated by make_model.
node
A character string. The quoted name of a node.
Value
Returns a list with the nodes that are not directly pointing into a node