Internal function to create parameter vector when list like arguments are provided
make_par_values_multiple(
model,
y = get_priors(model),
x = NA,
distribution = NA,
node = NA,
label = NA,
statement = NA,
confound = NA,
nodal_type = NA,
param_names = NA,
param_set = NA,
normalize = FALSE
)A model created with make_model
Vector of real non negative values to be changed
Vector of real non negative values to be substituted into y
String indicating a common prior distribution (uniform, jeffreys or certainty)
A string indicating nodes for which priors are to be altered
String. Label for nodal type indicating nodal types for which priors are to be altered
A causal query that determines nodal types for which priors are to be altered
A confound statement that restricts nodal types for which priors are to be altered
String. Label for nodal type indicating nodal types for which priors are to be altered
String. The name of specific parameter in the form of, for example, 'X.1', 'Y.01'
String. Indicates the name of the set of parameters to be modified (useful when setting confounds)
Logical. If TRUE normalizes such that param set probabilities sum to 1.
Other priors:
get_priors(),
make_par_values(),
make_priors(),
make_values_task_list(),
set_priors()