Learn R Programming

CausalQueries (version 0.0.3)

make_parameter_matrix: Make parameter matrix

Description

Calculate parameter matrix assuming no confounding. The parameter matrix maps from parameters into causal types. In models without confounding parameters correspond to nodal types.

Usage

make_parameter_matrix(model)

Arguments

model

A causal_model. A model object generated by make_model.

Value

A data.frame, the parameter matrix, mapping from parameters to causal types

Examples

Run this code
# NOT RUN {
model <- make_model('X -> Y')
make_parameter_matrix(model)
# }

Run the code above in your browser using DataLab