Learn R Programming

CausalQueries (version 0.0.3)

perm: Produces the possible permutations of a set of nodes

Description

Produces the possible permutations of a set of nodes

Usage

perm(max = rep(1, 2))

Arguments

max

A vector of integers. The maximum value of an integer value starting at 0. Defaults to 1. The number of permutation is defined by max's length

Value

A matrix of permutations

Examples

Run this code
# NOT RUN {
CausalQueries:::perm(3)
# }

Run the code above in your browser using DataLab