var_in_query: List of nodes contained in query
Description
List of nodes contained in query
Usage
var_in_query(model, query)
Value
A vector indicating which variables are included in a query
Arguments
- model
A causal_model. A model object generated by make_model.
- query
A character string. An expression defining nodal types to interrogate realise_outcomes. An expression of the form "Y[X=1]" asks for the value of Y when X is set to 1