Create parameter documentation to inherit
CausalQueries_internal_inherit_params(
model,
query,
join_by,
parameters,
P,
A,
data,
data_events,
node,
statement,
using,
n_draws
)A causal_model. A model object generated by make_model.
A character string. An expression defining nodal types to interrogate reveal_outcomes
A logical operator. Used to connect causal statements: AND ('&') or OR ('|'). Defaults to '|'.
A vector of real numbers in [0,1]. Values of parameters to specify (optional). By default, parameters is drawn from model$parameters_df.
A data.frame. Parameter matrix. Not required but may be provided to avoid repeated computation for simulations.
A data.frame. Ambiguity matrix. Not required but may be provided to avoid repeated computation for simulations.
A data.frame. Data of nodes that can take three values: 0, 1, and NA. In long form as generated by make_events
A data.frame. It must be compatible with nodes in model. The default columns are event, strategy and count.
A character string. The quoted name of a node.
A character string. A quoted causal statement.
A character string. It indicates whether to use `priors`, `posteriors` or `parameters`.
An integer. If no prior distribution is provided, generate prior distribution with n_draws number of draws.
This function does not return anything. It is used to inherit roxygen documentation