powered by
Slightly hacky function to continue param_set names in a sequence
continue_names(x, split = "_")
A vector with strings of the form c('x_1', 'x_2')
String on which to split. String should appear only once in each vector entry.
a vector with parameter names sequentially created with respect to x
x
# NOT RUN { x <- c('S_2', 'S_3', 'S_5') CausalQueries:::continue_names(x) # }
Run the code above in your browser using DataLab