powered by
Using parameters, priors, or posteriors
get_param_dist(model, using, n_draws = 4000)
A causal_model. A model object generated by make_model.
causal_model
make_model
A character string. It indicates whether to use `priors`, `posteriors` or `parameters`.
An integer. If no prior distribution is provided, generate prior distribution with n_draws number of draws.
n_draws
A matrix with the distribution of the parameters in the model
matrix
# NOT RUN { get_param_dist(model = make_model('X->Y'), using = 'priors', n_draws = 4) get_param_dist(model = make_model('X->Y'), using = 'parameters') # }
Run the code above in your browser using DataLab