Learn R Programming

CausalQueries (version 0.0.3)

get_parameter_names: Get parameter names

Description

Parameter names taken from P matrix or model if no P matrix provided

Usage

get_parameter_names(model, include_paramset = TRUE)

Arguments

model

A causal_model. A model object generated by make_model.

include_paramset

Logical. Whether to include the param set prefix as part of the name.

Value

A character vector with the names of the parameters in the model

Examples

Run this code
# NOT RUN {
get_parameter_names(make_model('X->Y'))

# }

Run the code above in your browser using DataLab