Learn R Programming

CausalQueries (version 0.0.3)

get_parents: Get list of parents of all nodes in a model

Description

Get list of parents of all nodes in a model

Usage

get_parents(model)

Arguments

model

A causal_model. A model object generated by make_model.

Value

A list of parents in a DAG

Examples

Run this code
# NOT RUN {
model <- make_model('X -> K -> Y')
get_parents(model)
# }

Run the code above in your browser using DataLab