powered by
Compute the sum of causal types probabilities. A model is flagged as improper if the sum is different than one.
is_improper(model)
A logical expression indicating whether a model is improper
A causal_model. A model object generated by make_model.
causal_model
make_model