powered by
Produces the possible permutations of a set of nodes
perm(max = rep(1, 2))
A vector of integers. The maximum value of an integer value starting at 0. Defaults to 1. The number of permutation is defined by max's length
max
A matrix of permutations
matrix
# NOT RUN { CausalQueries:::perm(3) # }
Run the code above in your browser using DataLab