Reduce nodal types using labels
restrict_by_labels(model, labels, keep = FALSE)A causal_model. A model object generated by make_model.
A list of character vectors specifying nodal types to be kept or removed from the model.
Logical. If `FALSE`, removes and if `TRUE` keeps only causal types specified by restriction.
An object of class causal_model. The causal types and nodal types in the model are reduced according to the stated restriction.
Other restrictions:
restrict_by_query(),
set_restrictions()