Reduce nodal types
restrict_by_query(model, statement, join_by = "|", keep = FALSE)a model created by make_model()
a list of character vectors specifying nodal types to be removed from the model. Use get_nodal_types to see syntax.
A string or a list of strings. The logical operator joining expanded types when statement contains wildcard (.). Can take values '&' (logical AND) or '|' (logical OR). When restriction contains wildcard (.) and join_by is not specified, it defaults to '|', otherwise it defaults to NULL.
Logical. If `FALSE`, removes and if `TRUE` keeps only causal types specified by restriction.
An object of class causal_model. The causal types and nodal types in the model are reduced according to the stated restriction.
Other restrictions:
restrict_by_labels(),
set_restrictions()