A causal_model. A model object generated by make_model.
P
A data.frame. Parameter matrix. Not required but may be provided to avoid repeated computation for simulations.
Value
An object of class causal_model. It essentially returns a list containing the elements comprising
a model (e.g. 'statement', 'nodal_types' and 'DAG') with the parameter matrix attached to it.